<elements>
  <summary>
    <attribution license="cc4" from="Microsoft" modified="false" />
    <para>The System.IO namespace contains types that allow reading and writing to files and data streams, and types that provide basic file and directory support.</para>
  </summary>
  <remarks>To be added.</remarks>
  <class name="BinaryReader" fullname="System.IO.BinaryReader" assembly="mscorlib">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>Reads primitive data types as binary values in a specific encoding.</para>
    </summary>
    <remarks>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>For a list of common I/O tasks, see <format type="text/html"><a href="bf00c380-706a-4e38-b829-454a480629fc">Common I/O Tasks</a></format>.</para>
    </remarks>
  </class>
  <class name="BinaryWriter" fullname="System.IO.BinaryWriter" assembly="mscorlib">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>Writes primitive types in binary to a stream and supports writing strings in a specific encoding.</para>
    </summary>
    <remarks>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>For a list of common I/O tasks, see <format type="text/html"><a href="bf00c380-706a-4e38-b829-454a480629fc">Common I/O Tasks</a></format>.</para>
    </remarks>
  </class>
  <class name="BufferedStream" fullname="System.IO.BufferedStream" assembly="mscorlib">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>Adds a buffering layer to read and write operations on another stream. This class cannot be inherited.</para>
    </summary>
    <remarks>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>A shared read/write buffer is allocated the first time a BufferedStream object is initialized with this constructor. The shared buffer is not used if all reads and writes are greater than or equal to <paramref name="bufferSize" />.</para>
    </remarks>
  </class>
  <class name="Directory" fullname="System.IO.Directory" assembly="mscorlib">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>Exposes static methods for creating, moving, and enumerating through directories and subdirectories. This class cannot be inherited.</para>
    </summary>
    <remarks>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>Any and all directories specified in <paramref name="path" /> are created, unless they already exist or unless some part of <paramref name="path" /> is invalid. If the directory already exists, this method does not create a new directory, but it returns a <see cref="T:System.IO.DirectoryInfo" /> object for the existing directory. </para>
      <para>The <paramref name="path" /> parameter specifies a directory path, not a file path.</para>
      <para>Trailing spaces are removed from the end of the <paramref name="path" /> parameter before creating the directory.</para>
      <para>You can create a directory on a remote computer, on a share that you have write access to. UNC paths are supported; for example, you can specify the following for <paramref name="path" />: \\2009\Archives\December in Visual Basic, and \\\\2009\\Archives\\December in C#. </para>
      <para>Creating a directory with only the colon character (:) is not supported, and will cause a NotSupportedException to be thrown.</para>
    </remarks>
  </class>
  <class name="DirectoryInfo" fullname="System.IO.DirectoryInfo" assembly="mscorlib">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>Exposes instance methods for creating, moving, and enumerating through directories and subdirectories. This class cannot be inherited.</para>
    </summary>
    <remarks>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>This constructor does not check if a directory exists. This constructor is a placeholder for a string that is used to access the disk in subsequent operations.</para>
      <para>The <paramref name="path" /> parameter can be a file name, including a file on a Universal Naming Convention (UNC) share.</para>
      <block subset="none" type="note">
        <para>When you compile a set of characters with a particular cultural setting and retrieve those same characters with a different cultural setting, the characters might not be interpretable, and could cause an exception to be thrown.</para>
      </block>
      <para>For a list of common I/O tasks, see <format type="text/html"><a href="bf00c380-706a-4e38-b829-454a480629fc">Common I/O Tasks</a></format>.</para>
    </remarks>
  </class>
  <class name="DirectoryNotFoundException" fullname="System.IO.DirectoryNotFoundException" assembly="mscorlib">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>The exception that is thrown when part of a file or directory cannot be found.</para>
    </summary>
    <remarks>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>This constructor initializes the <see cref="P:System.Exception.Message" /> property of the new instance to a system-supplied message that describes the error, such as "Could not find the specified directory." This message takes into account the current system culture.</para>
      <para>The <see cref="P:System.Exception.InnerException" /> property of the new instance is initialized to null.</para>
    </remarks>
  </class>
  <class name="DriveInfo" fullname="System.IO.DriveInfo" assembly="mscorlib">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>Provides access to information on a drive.</para>
    </summary>
    <remarks>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>Use this class to obtain information on drives. The drive name must be either an uppercase or lowercase letter from 'a' to 'z'. You cannot use this method to obtain information on drive names that are null or use UNC (\\server\share) paths.</para>
    </remarks>
  </class>
  <class name="DriveNotFoundException" fullname="System.IO.DriveNotFoundException" assembly="mscorlib">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>The exception that is thrown when trying to access a drive or share that is not available.</para>
    </summary>
    <remarks>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>This constructor initializes the <see cref="P:System.Exception.Message" /> property of the new instance to a system-supplied message that describes the error, such as "Could not find the specified directory." This message is localized based on the current system culture.</para>
      <para>The <see cref="P:System.Exception.InnerException" /> property of the new instance is initialized to null.</para>
    </remarks>
  </class>
  <class name="DriveType" fullname="System.IO.DriveType" assembly="mscorlib">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>Defines constants for drive types, including CDRom, Fixed, Network, NoRootDirectory, Ram, Removable, and Unknown.</para>
    </summary>
    <remarks />
  </class>
  <class name="EndOfStreamException" fullname="System.IO.EndOfStreamException" assembly="mscorlib">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>The exception that is thrown when reading is attempted past the end of a stream.</para>
    </summary>
    <remarks>
      <para>This constructor initializes the <see cref="!:System.IO.EndOfStreamException.Message" /> property of the new instance to
   a system-supplied message that describes the error, such as "Attempted to read
   past the end of the stream." This message takes into account the current system
   culture.</para>
      <para>The <see cref="!:System.IO.EndOfStreamException.InnerException" /> property of the new instance is 
initialized to <see langword="null" /> .</para>
    </remarks>
  </class>
  <class name="File" fullname="System.IO.File" assembly="mscorlib">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>Provides static methods for the creation, copying, deletion, moving, and opening of files, and aids in the creation of <see cref="T:System.IO.FileStream" /> objects.</para>
    </summary>
    <remarks>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>The method creates the file if it doesn’t exist, but it doesn't create new directories. Therefore, the value of the <paramref name="path" /> parameter must contain existing directories.</para>
    </remarks>
  </class>
  <class name="FileAccess" fullname="System.IO.FileAccess" assembly="mscorlib">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>Defines constants for read, write, or read/write access to a file.</para>
    </summary>
    <remarks>To be added.</remarks>
  </class>
  <class name="FileAttributes" fullname="System.IO.FileAttributes" assembly="mscorlib">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>Provides attributes for files and directories.</para>
    </summary>
    <remarks>To be added</remarks>
  </class>
  <class name="FileInfo" fullname="System.IO.FileInfo" assembly="mscorlib">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>Provides properties and instance methods for the creation, copying, deletion, moving, and opening of files, and aids in the creation of <see cref="T:System.IO.FileStream" /> objects. This class cannot be inherited.</para>
    </summary>
    <remarks>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>You can specify either the fully qualified or the relative file name, but the security check gets the fully qualified name.</para>
    </remarks>
  </class>
  <class name="FileLoadException" fullname="System.IO.FileLoadException" assembly="mscorlib">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>The exception that is thrown when a managed assembly is found but cannot be loaded.</para>
    </summary>
    <remarks>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>The <see cref="P:System.Exception.InnerException" /> property and <see cref="P:System.IO.FileLoadException.FileName" /> property of the new instance are initialized to null.</para>
    </remarks>
  </class>
  <class name="FileMode" fullname="System.IO.FileMode" assembly="mscorlib">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>Specifies how the operating system should open a file.</para>
    </summary>
    <remarks>To be added.</remarks>
  </class>
  <class name="FileNotFoundException" fullname="System.IO.FileNotFoundException" assembly="mscorlib">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>The exception that is thrown when an attempt to access a file that does not exist on disk fails.</para>
    </summary>
    <remarks>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>This constructor initializes the <see cref="P:System.IO.FileNotFoundException.Message" /> property of the new instance to a system-supplied message that describes the error, such as "Could not find the specified file." This message takes into account the current system culture.</para>
    </remarks>
  </class>
  <class name="FileOptions" fullname="System.IO.FileOptions" assembly="mscorlib">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>Represents advanced options for creating a <see cref="T:System.IO.FileStream" /> object.</para>
    </summary>
    <remarks>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>Specifying this flag can increase performance for applications that read large files using sequential access. Performance gains can be even more noticeable for applications that read large files mostly sequentially, but occasionally skip over small ranges of bytes.</para>
    </remarks>
  </class>
  <class name="FileShare" fullname="System.IO.FileShare" assembly="mscorlib">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>Contains constants for controlling the kind of access other <see cref="T:System.IO.FileStream" /> objects can have to the same file.</para>
    </summary>
    <remarks>To be added.</remarks>
  </class>
  <class name="FileStream" fullname="System.IO.FileStream" assembly="mscorlib">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>Exposes a <see cref="T:System.IO.Stream" /> around a file, supporting both synchronous and asynchronous read and write operations.</para>
    </summary>
    <remarks>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>When <see cref="M:System.IO.Stream.Close" /> is called, the handle is also closed and the file's handle count is decremented.</para>
      <para>FileStream assumes that it has exclusive control over the handle. Reading, writing, or seeking while a FileStream is also holding a handle could result in data corruption. For data safety, call <see cref="M:System.IO.FileStream.Flush" /> before using the handle, and avoid calling any methods other than Close after you are done using the handle.</para>
      <block subset="none" type="note">
        <para>When you compile a set of characters with a particular cultural setting and retrieve those same characters with a different cultural setting, the characters might not be interpretable, and could cause an exception to be thrown.</para>
      </block>
      <para>FileShare.Read is the default for those <see cref="T:System.IO.FileStream" /> constructors without a FileShare parameter.</para>
      <para>For a list of common file and directory operations, see <format type="text/html"><a href="bf00c380-706a-4e38-b829-454a480629fc">Common I/O Tasks</a></format>.</para>
    </remarks>
  </class>
  <class name="FileSystemInfo" fullname="System.IO.FileSystemInfo" assembly="mscorlib">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>Provides the base class for both <see cref="T:System.IO.FileInfo" /> and <see cref="T:System.IO.DirectoryInfo" /> objects.</para>
    </summary>
    <remarks>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>For a list of common I/O tasks, see <format type="text/html"><a href="bf00c380-706a-4e38-b829-454a480629fc">Common I/O Tasks</a></format>.</para>
    </remarks>
  </class>
  <class name="IOException" fullname="System.IO.IOException" assembly="mscorlib">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>The exception that is thrown when an I/O error occurs.</para>
    </summary>
    <remarks>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>The constructor initializes the <see cref="P:System.Exception.Message" /> property of the new instance to a system-supplied message that describes the error, such as "An I/O error occurred while performing the requested operation." This message takes into account the current system culture.</para>
    </remarks>
  </class>
  <class name="MemoryStream" fullname="System.IO.MemoryStream" assembly="mscorlib">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>Creates a stream whose backing store is memory.</para>
    </summary>
    <remarks>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>The <see cref="P:System.IO.MemoryStream.CanRead" />, <see cref="P:System.IO.MemoryStream.CanSeek" />, and <see cref="P:System.IO.MemoryStream.CanWrite" /> properties are all set to true.</para>
      <para>The capacity of the current stream automatically increases when you use the <see cref="M:System.IO.MemoryStream.SetLength(System.Int64)" /> method to set the length to a value larger than the capacity of the current stream.</para>
      <para>This constructor exposes the underlying stream, which <see cref="M:System.IO.MemoryStream.GetBuffer" /> returns.</para>
    </remarks>
  </class>
  <class name="Path" fullname="System.IO.Path" assembly="mscorlib">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>Performs operations on <see cref="T:System.String" /> instances that contain file or directory path information. These operations are performed in a cross-platform manner.</para>
    </summary>
    <remarks>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>The character stored in this field cannot be in <see cref="F:System.IO.Path.InvalidPathChars" />. This field can be set to the same value as <see cref="F:System.IO.Path.DirectorySeparatorChar" />. AltDirectorySeparatorChar and DirectorySeparatorChar are both valid for separating directory levels in a path string.</para>
      <para>The value of this field is a backslash ('\') on UNIX, and a slash ('/') on Windows and Macintosh operating systems.</para>
    </remarks>
  </class>
  <class name="PathTooLongException" fullname="System.IO.PathTooLongException" assembly="mscorlib">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>The exception that is thrown when a path or file name is longer than the system-defined maximum length.</para>
    </summary>
    <remarks>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>This constructor initializes the <see cref="P:System.Exception.Message" /> property of the new instance to a system-supplied message that describes the error, such as "The supplied path is too long." This message takes into account the current system culture.</para>
    </remarks>
  </class>
  <class name="SearchOption" fullname="System.IO.SearchOption" assembly="mscorlib">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>Specifies whether to search the current directory, or the current directory and all subdirectories. </para>
    </summary>
    <remarks />
  </class>
  <class name="SeekOrigin" fullname="System.IO.SeekOrigin" assembly="mscorlib">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>Specifies the position in a stream to use for seeking.</para>
    </summary>
    <remarks>To be added.</remarks>
  </class>
  <class name="Stream" fullname="System.IO.Stream" assembly="mscorlib">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>Provides a generic view of a sequence of bytes. This is an abstract class.</para>
    </summary>
    <remarks>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>
        <see cref="T:System.IO.Stream" /> is the abstract base class of all streams. </para>
      <para>Some of the more commonly used streams that inherit from <see cref="T:System.IO.Stream" /> are <see cref="T:System.IO.FileStream" />, and <see cref="T:System.IO.MemoryStream" />.</para>
    </remarks>
  </class>
  <class name="StreamReader" fullname="System.IO.StreamReader" assembly="mscorlib">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>Implements a <see cref="T:System.IO.TextReader" /> that reads characters from a byte stream in a particular encoding.</para>
    </summary>
    <remarks>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>This constructor initializes the encoding to <see cref="T:System.Text.UTF8Encoding" />, the <see cref="P:System.IO.StreamReader.BaseStream" /> property using the <paramref name="stream" /> parameter, and the internal buffer size to 1024 bytes.</para>
      <para>The <see cref="T:System.IO.StreamReader" /> object calls <see cref="M:System.IO.Stream.Dispose" /> on the provided <see cref="T:System.IO.Stream" /> object when <see cref="M:System.IO.StreamReader.Dispose(System.Boolean)" /> is called. </para>
      <block subset="none" type="note">
        <para>When you compile a set of characters with a particular cultural setting and retrieve those same characters with a different cultural setting, the characters might not be interpretable, and could cause an exception to be thrown.</para>
      </block>
      <para>For a list of common I/O tasks, see <format type="text/html"><a href="bf00c380-706a-4e38-b829-454a480629fc">Common I/O Tasks</a></format>.</para>
    </remarks>
  </class>
  <class name="StreamWriter" fullname="System.IO.StreamWriter" assembly="mscorlib">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>Implements a <see cref="T:System.IO.TextWriter" /> for writing characters to a stream in a particular encoding.</para>
    </summary>
    <remarks>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>This constructor creates a <see cref="T:System.IO.StreamWriter" /> with UTF-8 encoding without a Byte-Order Mark (BOM), so its <see cref="M:System.Text.Encoding.GetPreamble" /> method returns an empty byte array. The default UTF-8 encoding for this constructor throws an exception on invalid bytes. This behavior is different from the behavior provided by the encoding object in the <see cref="P:System.Text.Encoding.UTF8" /> property. To specify whether an exception is thrown on invalid bytes, use a constructor that accepts an encoding object as a parameter, such as <see cref="M:System.IO.StreamWriter.#ctor(System.IO.Stream,System.Text.Encoding)" />. The <see cref="P:System.IO.StreamWriter.BaseStream" /> property is initialized using the <paramref name="stream" /> parameter. The position of the stream is not reset.</para>
      <para>The <see cref="T:System.IO.StreamWriter" /> object calls <see cref="M:System.IO.Stream.Dispose" /> on the provided <see cref="T:System.IO.Stream" /> object when <see cref="M:System.IO.StreamWriter.Dispose(System.Boolean)" /> is called.</para>
      <block subset="none" type="note">
        <para>When you compile a set of characters with a particular cultural setting and retrieve those same characters with a different cultural setting, the characters might not be interpretable and could cause an exception to be thrown.</para>
      </block>
      <para>For a list of common I/O tasks, see <format type="text/html"><a href="bf00c380-706a-4e38-b829-454a480629fc">Common I/O Tasks</a></format>.</para>
    </remarks>
  </class>
  <class name="StringReader" fullname="System.IO.StringReader" assembly="mscorlib">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>Implements a <see cref="T:System.IO.TextReader" /> that reads from a string.</para>
    </summary>
    <remarks>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>The following table lists examples of other typical or related I/O tasks.</para>
      <list type="table">
        <listheader>
          <item>
            <term>
              <para>To do this... </para>
            </term>
            <description>
              <para>See the example in this topic... </para>
            </description>
          </item>
        </listheader>
        <item>
          <term>
            <para>Create a text file. </para>
          </term>
          <description>
            <para>
              <format type="text/html">
                <a href="060CBE06-2ADF-4337-9E7B-961A5C840208">[&lt;topic://cpconwritingtexttofile&gt;]</a>
              </format>
            </para>
          </description>
        </item>
        <item>
          <term>
            <para>Write to a text file. </para>
          </term>
          <description>
            <para>
              <format type="text/html">
                <a href="060CBE06-2ADF-4337-9E7B-961A5C840208">[&lt;topic://cpconwritingtexttofile&gt;]</a>
              </format>
            </para>
          </description>
        </item>
        <item>
          <term>
            <para>Read from a text file. </para>
          </term>
          <description>
            <para>
              <format type="text/html">
                <a href="ED180BAA-DFC6-4C69-A725-46E87EDAFB27">[&lt;topic://cpconreadingtextfromfile&gt;]</a>
              </format>
            </para>
          </description>
        </item>
        <item>
          <term>
            <para>Append text to a file. </para>
          </term>
          <description>
            <para>
              <format type="text/html">
                <a href="74423362-1721-49CB-AA0A-E04005F72A06">[&lt;topic://cpconopeningappendingtologfile&gt;]</a>
              </format>
            </para>
            <para>
              <see cref="M:System.IO.File.AppendText(System.String)" />
            </para>
            <para>
              <see cref="M:System.IO.FileInfo.AppendText" />
            </para>
          </description>
        </item>
        <item>
          <term>
            <para>Get the size of a file. </para>
          </term>
          <description>
            <para>
              <see cref="P:System.IO.FileInfo.Length" />
            </para>
          </description>
        </item>
        <item>
          <term>
            <para>Get the attributes of a file. </para>
          </term>
          <description>
            <para>
              <see cref="M:System.IO.File.GetAttributes(System.String)" />
            </para>
          </description>
        </item>
        <item>
          <term>
            <para>Set the attributes of a file. </para>
          </term>
          <description>
            <para>
              <see cref="M:System.IO.File.SetAttributes(System.String,System.IO.FileAttributes)" />
            </para>
          </description>
        </item>
        <item>
          <term>
            <para>Determine if a file exists. </para>
          </term>
          <description>
            <para>
              <see cref="M:System.IO.File.Exists(System.String)" />
            </para>
          </description>
        </item>
        <item>
          <term>
            <para>Read from a binary file. </para>
          </term>
          <description>
            <para>
              <format type="text/html">
                <a href="E209D949-31E8-44EA-8E38-87F9093F3093">[&lt;topic://cpconReadingWritingToNewlyCreatedDataFile&gt;]</a>
              </format>
            </para>
          </description>
        </item>
        <item>
          <term>
            <para>Write to a binary file. </para>
          </term>
          <description>
            <para>
              <format type="text/html">
                <a href="E209D949-31E8-44EA-8E38-87F9093F3093">[&lt;topic://cpconReadingWritingToNewlyCreatedDataFile&gt;]</a>
              </format>
            </para>
          </description>
        </item>
      </list>
    </remarks>
  </class>
  <class name="StringWriter" fullname="System.IO.StringWriter" assembly="mscorlib">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>Implements a <see cref="T:System.IO.TextWriter" /> for writing information to a string. The information is stored in an underlying <see cref="T:System.Text.StringBuilder" />.</para>
    </summary>
    <remarks>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>A new <see cref="T:System.Text.StringBuilder" /> is automatically created and associated with the new StringWriter.</para>
      <para>The following table lists examples of other typical or related I/O tasks.</para>
      <list type="table">
        <listheader>
          <item>
            <term>
              <para>To do this... </para>
            </term>
            <description>
              <para>See the example in this topic... </para>
            </description>
          </item>
        </listheader>
        <item>
          <term>
            <para>Create a text file. </para>
          </term>
          <description>
            <para>
              <format type="text/html">
                <a href="060CBE06-2ADF-4337-9E7B-961A5C840208">[&lt;topic://cpconwritingtexttofile&gt;]</a>
              </format>
            </para>
          </description>
        </item>
        <item>
          <term>
            <para>Write to a text file. </para>
          </term>
          <description>
            <para>
              <format type="text/html">
                <a href="060CBE06-2ADF-4337-9E7B-961A5C840208">[&lt;topic://cpconwritingtexttofile&gt;]</a>
              </format>
            </para>
          </description>
        </item>
        <item>
          <term>
            <para>Read from a text file. </para>
          </term>
          <description>
            <para>
              <format type="text/html">
                <a href="ED180BAA-DFC6-4C69-A725-46E87EDAFB27">[&lt;topic://cpconreadingtextfromfile&gt;]</a>
              </format>
            </para>
          </description>
        </item>
        <item>
          <term>
            <para>Append text to a file. </para>
          </term>
          <description>
            <para>
              <format type="text/html">
                <a href="74423362-1721-49CB-AA0A-E04005F72A06">[&lt;topic://cpconopeningappendingtologfile&gt;]</a>
              </format>
            </para>
            <para>
              <see cref="M:System.IO.File.AppendText(System.String)" />
            </para>
            <para>
              <see cref="M:System.IO.FileInfo.AppendText" />
            </para>
          </description>
        </item>
        <item>
          <term>
            <para>Get the size of a file. </para>
          </term>
          <description>
            <para>
              <see cref="P:System.IO.FileInfo.Length" />
            </para>
          </description>
        </item>
        <item>
          <term>
            <para>Get the attributes of a file. </para>
          </term>
          <description>
            <para>
              <see cref="M:System.IO.File.GetAttributes(System.String)" />
            </para>
          </description>
        </item>
        <item>
          <term>
            <para>Set the attributes of a file. </para>
          </term>
          <description>
            <para>
              <see cref="M:System.IO.File.SetAttributes(System.String,System.IO.FileAttributes)" />
            </para>
          </description>
        </item>
        <item>
          <term>
            <para>Determine if a file exists. </para>
          </term>
          <description>
            <para>
              <see cref="M:System.IO.File.Exists(System.String)" />
            </para>
          </description>
        </item>
        <item>
          <term>
            <para>Read from a binary file. </para>
          </term>
          <description>
            <para>
              <format type="text/html">
                <a href="E209D949-31E8-44EA-8E38-87F9093F3093">[&lt;topic://cpconReadingWritingToNewlyCreatedDataFile&gt;]</a>
              </format>
            </para>
          </description>
        </item>
        <item>
          <term>
            <para>Write to a binary file. </para>
          </term>
          <description>
            <para>
              <format type="text/html">
                <a href="E209D949-31E8-44EA-8E38-87F9093F3093">[&lt;topic://cpconReadingWritingToNewlyCreatedDataFile&gt;]</a>
              </format>
            </para>
          </description>
        </item>
      </list>
    </remarks>
  </class>
  <class name="TextReader" fullname="System.IO.TextReader" assembly="mscorlib">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>Represents a reader that can read a sequential series of characters.</para>
    </summary>
    <remarks>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>Use this constructor for derived classes.</para>
    </remarks>
  </class>
  <class name="TextWriter" fullname="System.IO.TextWriter" assembly="mscorlib">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>Represents a writer that can write a sequential series of characters. This class is abstract.</para>
    </summary>
    <remarks>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>Use this constructor overload when you do not want to provide a value for the <see cref="P:System.IO.TextWriter.FormatProvider" /> property. When the <see cref="P:System.IO.TextWriter.FormatProvider" /> property is null, the culture of the current thread is used for formatting.</para>
      <para>Use this constructor for derived classes.</para>
      <para>For a list of common I/O tasks, see <format type="text/html"><a href="bf00c380-706a-4e38-b829-454a480629fc">Common I/O Tasks</a></format>.</para>
    </remarks>
  </class>
  <class name="UnmanagedMemoryAccessor" fullname="System.IO.UnmanagedMemoryAccessor" assembly="mscorlib">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>Provides random access to unmanaged blocks of memory from managed code.</para>
    </summary>
    <remarks>To be added.</remarks>
  </class>
  <class name="UnmanagedMemoryStream" fullname="System.IO.UnmanagedMemoryStream" assembly="mscorlib">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>Provides access to unmanaged blocks of memory from managed code.</para>
    </summary>
    <remarks>To be added.</remarks>
  </class>
  <class name="HandleInheritability" fullname="System.IO.HandleInheritability" assembly="System.Core">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>Specifies whether the underlying handle is inheritable by child processes.</para>
    </summary>
    <remarks />
  </class>
  <class name="ErrorEventArgs" fullname="System.IO.ErrorEventArgs" assembly="System">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>Provides data for the <see cref="E:System.IO.FileSystemWatcher.Error" /> event.</para>
    </summary>
    <remarks>To be added</remarks>
  </class>
  <class name="ErrorEventHandler" fullname="System.IO.ErrorEventHandler" assembly="System">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>Represents the method that will handle the <see cref="E:System.IO.FileSystemWatcher.Error" /> event of a <see cref="T:System.IO.FileSystemWatcher" /> object.</para>
    </summary>
    <remarks />
  </class>
  <class name="FileSystemEventArgs" fullname="System.IO.FileSystemEventArgs" assembly="System">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>Provides data for the directory events: <see cref="E:System.IO.FileSystemWatcher.Changed" />, <see cref="E:System.IO.FileSystemWatcher.Created" />, <see cref="E:System.IO.FileSystemWatcher.Deleted" />.</para>
    </summary>
    <remarks>To be added</remarks>
  </class>
  <class name="FileSystemEventHandler" fullname="System.IO.FileSystemEventHandler" assembly="System">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>Represents the method that will handle the <see cref="E:System.IO.FileSystemWatcher.Changed" />, <see cref="E:System.IO.FileSystemWatcher.Created" />, or <see cref="E:System.IO.FileSystemWatcher.Deleted" /> event of a <see cref="T:System.IO.FileSystemWatcher" /> class.</para>
    </summary>
    <remarks />
  </class>
  <class name="FileSystemWatcher" fullname="System.IO.FileSystemWatcher" assembly="System">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>Listens to the file system change notifications and raises events when a directory, or file in a directory, changes.</para>
    </summary>
    <remarks>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>You cannot watch a remote computer that does not have Windows NT or Windows 2000. You cannot watch a remote Windows NT 4.0 computer from a Windows NT 4.0 computer.</para>
      <para>The following table shows initial property values for an instance of <see cref="T:System.IO.FileSystemWatcher" />.</para>
      <list type="table">
        <listheader>
          <item>
            <term>
              <para>Property </para>
            </term>
            <description>
              <para>Initial Value </para>
            </description>
          </item>
        </listheader>
        <item>
          <term>
            <para>
              <see cref="P:System.IO.FileSystemWatcher.NotifyFilter" />
            </para>
          </term>
          <description>
            <para>bitwise OR combination of LastWrite, FileName, and DirectoryName </para>
          </description>
        </item>
        <item>
          <term>
            <para>
              <see cref="P:System.IO.FileSystemWatcher.EnableRaisingEvents" />
            </para>
          </term>
          <description>
            <para>false </para>
          </description>
        </item>
        <item>
          <term>
            <para>
              <see cref="P:System.IO.FileSystemWatcher.Filter" />
            </para>
          </term>
          <description>
            <para>"*.*" (Watch all files.) </para>
          </description>
        </item>
        <item>
          <term>
            <para>
              <see cref="P:System.IO.FileSystemWatcher.IncludeSubdirectories" />
            </para>
          </term>
          <description>
            <para>false </para>
          </description>
        </item>
        <item>
          <term>
            <para>
              <see cref="P:System.IO.FileSystemWatcher.InternalBufferSize" />
            </para>
          </term>
          <description>
            <para>8192 </para>
          </description>
        </item>
        <item>
          <term>
            <para>
              <see cref="P:System.IO.FileSystemWatcher.Path" />
            </para>
          </term>
          <description>
            <para>empty string ("") </para>
          </description>
        </item>
      </list>
      <block subset="none" type="note">
        <para>The component will not watch the specified directory until the <see cref="P:System.IO.FileSystemWatcher.Path" /> is set, and <see cref="P:System.IO.FileSystemWatcher.EnableRaisingEvents" /> is true.</para>
      </block>
    </remarks>
  </class>
  <class name="InternalBufferOverflowException" fullname="System.IO.InternalBufferOverflowException" assembly="System">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>The exception thrown when the internal buffer overflows.</para>
    </summary>
    <remarks>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>These constructors are used by the component to signify an error. Only use them if extending the class or the .NET Framework. This exception indicates an internal buffer has overflowed and users should take appropriate steps in their code to ensure it recovers properly. The cause of the overflow is often too many changes in a short period of time, causing the internal notification buffer to overflow. To resolve this, use the <see cref="P:System.IO.FileSystemWatcher.NotifyFilter" /> and <see cref="P:System.IO.FileSystemWatcher.IncludeSubdirectories" /> properties to filter out unwanted change notifications. You can also increase the size of the internal buffer through the <see cref="P:System.IO.FileSystemWatcher.InternalBufferSize" /> property. However, increasing the size of the buffer is expensive, so keep the buffer as small as possible.</para>
    </remarks>
  </class>
  <class name="InvalidDataException" fullname="System.IO.InvalidDataException" assembly="System">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>The exception that is thrown when a data stream is in an invalid format.</para>
    </summary>
    <remarks>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>This constructor initializes the <see cref="P:System.Exception.Message" /> property of the new instance to a system-supplied message that describes the error, such as "An invalid argument was specified." This message is localized based on the current system culture.</para>
    </remarks>
  </class>
  <class name="IODescriptionAttribute" fullname="System.IO.IODescriptionAttribute" assembly="System">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>Sets the description visual designers can display when referencing an event, extender, or property.</para>
    </summary>
    <remarks>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>For more information about using attributes, see <format type="text/html"><a href="30386922-1E00-4602-9EBF-526B271A8B87">[&lt;topic://cpconExtendingMetadataUsingAttributes&gt;]</a></format>.</para>
    </remarks>
  </class>
  <class name="NotifyFilters" fullname="System.IO.NotifyFilters" assembly="System">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>Specifies changes to watch for in a file or folder.</para>
    </summary>
    <remarks>To be added</remarks>
  </class>
  <class name="RenamedEventArgs" fullname="System.IO.RenamedEventArgs" assembly="System">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>Provides data for the <see cref="E:System.IO.FileSystemWatcher.Renamed" /> event.</para>
    </summary>
    <remarks>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>This class inherits from the <see cref="T:System.IO.FileSystemEventArgs" /> class and extends it by adding an old name field to specify the previous name of the file or directory affected.</para>
    </remarks>
  </class>
  <class name="RenamedEventHandler" fullname="System.IO.RenamedEventHandler" assembly="System">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>Represents the method that will handle the <see cref="E:System.IO.FileSystemWatcher.Renamed" /> event of a <see cref="T:System.IO.FileSystemWatcher" /> class.</para>
    </summary>
    <remarks />
  </class>
  <class name="WaitForChangedResult" fullname="System.IO.WaitForChangedResult" assembly="System">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>Contains information on the change that occurred.</para>
    </summary>
    <remarks>To be added</remarks>
  </class>
  <class name="WatcherChangeTypes" fullname="System.IO.WatcherChangeTypes" assembly="System">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>Changes that might occur to a file or directory.</para>
    </summary>
    <remarks>To be added</remarks>
  </class>
</elements>