<elements>
  <summary>
    <attribution license="cc4" from="Microsoft" modified="false" />
    <para>The <see cref="N:System.Linq" /> namespace provides classes and interfaces that support queries that use vbteclinqext.</para>
  </summary>
  <remarks>
    <attribution license="cc4" from="Microsoft" modified="false" />
    <para>The <see cref="N:System.Linq" /> namespace is in the System.Core assembly (in System.Core.dll).</para>
    <para>The <see cref="T:System.Linq.Enumerable" /> class contains vbteclinq standard query operators that operate on objects that implement <see cref="T:System.Collections.Generic.IEnumerable`1" />.</para>
    <para>The <see cref="T:System.Linq.Queryable" /> class contains vbteclinq standard query operators that operate on objects that implement <see cref="T:System.Linq.IQueryable`1" />.</para>
    <para>For information about LINQ to SQL, see <format type="text/html"><a href="73d13345-eece-471a-af40-4cc7a2f11655">LINQ to SQL</a></format>.</para>
  </remarks>
  <class name="Enumerable" fullname="System.Linq.Enumerable" assembly="System.Core">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>Provides a set of static (Shared in Visual Basic) methods for querying objects that implement <see cref="T:System.Collections.Generic.IEnumerable`1" />.</para>
    </summary>
    <remarks>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>The <see cref="M:System.Linq.Enumerable.Aggregate``1(System.Collections.Generic.IEnumerable{``0},System.Func{``0,``0,``0})" /> method makes it simple to perform a calculation over a sequence of values. This method works by calling <paramref name="func" /> one time for each element in <paramref name="source" /> except the first one. Each time <paramref name="func" /> is called, <see cref="M:System.Linq.Enumerable.Aggregate``1(System.Collections.Generic.IEnumerable{``0},System.Func{``0,``0,``0})" /> passes both the element from the sequence and an aggregated value (as the first argument to <paramref name="func" />). The first element of <paramref name="source" /> is used as the initial aggregate value. The result of <paramref name="func" /> replaces the previous aggregated value. <see cref="M:System.Linq.Enumerable.Aggregate``1(System.Collections.Generic.IEnumerable{``0},System.Func{``0,``0,``0})" /> returns the final result of <paramref name="func" />.</para>
      <para>This overload of the <see cref="M:System.Linq.Enumerable.Aggregate``1(System.Collections.Generic.IEnumerable{``0},System.Func{``0,``0,``0})" /> method isn't suitable for all cases because it uses the first element of <paramref name="source" /> as the initial aggregate value. You should choose another overload if the return value should include only the elements of <paramref name="source" /> that meet a certain condition. For example, this overload isn't reliable if you want to calculate the sum of the even numbers in <paramref name="source" />. The result will be incorrect if the first element is odd instead of even.</para>
      <para>To simplify common aggregation operations, the standard query operators also include a general purpose count method, <see cref="M:System.Linq.Enumerable.Count``1(System.Collections.Generic.IEnumerable{``0})" />, and four numeric aggregation methods, namely <see cref="M:System.Linq.Enumerable.Min(System.Collections.Generic.IEnumerable{System.Decimal})" />, <see cref="M:System.Linq.Enumerable.Max(System.Collections.Generic.IEnumerable{System.Decimal})" />, <see cref="M:System.Linq.Enumerable.Sum(System.Collections.Generic.IEnumerable{System.Decimal})" />, and <see cref="M:System.Linq.Enumerable.Average(System.Collections.Generic.IEnumerable{System.Decimal})" />.</para>
    </remarks>
  </class>
  <class name="EnumerableExecutor" fullname="System.Linq.EnumerableExecutor" assembly="System.Core">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>Represents an expression tree and provides functionality to execute the expression tree after rewriting it.</para>
    </summary>
    <remarks>To be added.</remarks>
  </class>
  <class name="EnumerableExecutor&lt;T&gt;" fullname="System.Linq.EnumerableExecutor&lt;T&gt;" assembly="System.Core">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>Represents an expression tree and provides functionality to execute the expression tree after rewriting it.</para>
    </summary>
    <remarks>To be added.</remarks>
  </class>
  <class name="EnumerableQuery" fullname="System.Linq.EnumerableQuery" assembly="System.Core">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>Represents an <see cref="T:System.Collections.IEnumerable" /> as an <see cref="T:System.Linq.EnumerableQuery" /> data source. </para>
    </summary>
    <remarks>To be added.</remarks>
  </class>
  <class name="EnumerableQuery&lt;T&gt;" fullname="System.Linq.EnumerableQuery&lt;T&gt;" assembly="System.Core">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>Represents an <see cref="T:System.Collections.Generic.IEnumerable`1" /> collection as an <see cref="T:System.Linq.IQueryable`1" /> data source.</para>
    </summary>
    <remarks>To be added.</remarks>
  </class>
  <class name="IGrouping&lt;TKey,TElement&gt;" fullname="System.Linq.IGrouping&lt;TKey,TElement&gt;" assembly="System.Core">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>Represents a collection of objects that have a common key.</para>
    </summary>
    <remarks>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>The key of an <see cref="T:System.Linq.IGrouping`2" /> represents the attribute that is common to each value in the <see cref="T:System.Linq.IGrouping`2" />.</para>
    </remarks>
  </class>
  <class name="ILookup&lt;TKey,TElement&gt;" fullname="System.Linq.ILookup&lt;TKey,TElement&gt;" assembly="System.Core">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>Defines an indexer, size property, and Boolean search method for data structures that map keys to <see cref="T:System.Collections.Generic.IEnumerable`1" /> sequences of values.</para>
    </summary>
    <remarks>To be added.</remarks>
  </class>
  <class name="IOrderedEnumerable&lt;TElement&gt;" fullname="System.Linq.IOrderedEnumerable&lt;TElement&gt;" assembly="System.Core">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>Represents a sorted sequence.</para>
    </summary>
    <remarks>To be added.</remarks>
  </class>
  <class name="IOrderedQueryable" fullname="System.Linq.IOrderedQueryable" assembly="System.Core">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>Represents the result of a sorting operation.</para>
    </summary>
    <remarks />
  </class>
  <class name="IOrderedQueryable&lt;T&gt;" fullname="System.Linq.IOrderedQueryable&lt;T&gt;" assembly="System.Core">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>Represents the result of a sorting operation.</para>
    </summary>
    <remarks />
  </class>
  <class name="IQueryable" fullname="System.Linq.IQueryable" assembly="System.Core">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>Provides functionality to evaluate queries against a specific data source wherein the type of the data is not specified.</para>
    </summary>
    <remarks>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>The <see cref="P:System.Linq.IQueryable.ElementType" /> property represents the "T" in IQueryable&lt;T&gt; or IQueryable(Of T).</para>
    </remarks>
  </class>
  <class name="IQueryable&lt;T&gt;" fullname="System.Linq.IQueryable&lt;T&gt;" assembly="System.Core">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>Provides functionality to evaluate queries against a specific data source wherein the type of the data is known.</para>
    </summary>
    <remarks />
  </class>
  <class name="IQueryProvider" fullname="System.Linq.IQueryProvider" assembly="System.Core">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>Defines methods to create and execute queries that are described by an <see cref="T:System.Linq.IQueryable" /> object.</para>
    </summary>
    <remarks>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <block subset="none" type="note">
        <para>The <see cref="P:System.Linq.IQueryable.Expression" /> property of the returned <see cref="T:System.Linq.IQueryable" /> object is equal to <paramref name="expression" />.</para>
      </block>
      <para>The <see cref="M:System.Linq.IQueryProvider.CreateQuery(System.Linq.Expressions.Expression)" /> method is used to create new <see cref="T:System.Linq.IQueryable" /> objects, given an expression tree. The query that is represented by the returned object is associated with a specific LINQ provider.</para>
      <para>Several of the standard query operator methods defined in <see cref="T:System.Linq.Queryable" />, such as <see cref="M:System.Linq.Queryable.OfType``1(System.Linq.IQueryable)" /> and <see cref="M:System.Linq.Queryable.Cast``1(System.Linq.IQueryable)" />, call this method. They pass it a <see cref="T:System.Linq.Expressions.MethodCallExpression" /> that represents a vbteclinq query.</para>
    </remarks>
  </class>
  <class name="Lookup&lt;TKey,TElement&gt;" fullname="System.Linq.Lookup&lt;TKey,TElement&gt;" assembly="System.Core">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>Represents a collection of keys each mapped to one or more values.</para>
    </summary>
    <remarks>To be added.</remarks>
  </class>
  <class name="OrderedParallelQuery&lt;TSource&gt;" fullname="System.Linq.OrderedParallelQuery&lt;TSource&gt;" assembly="System.Core">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>Represents a sorted, parallel sequence.</para>
    </summary>
    <remarks>To be added.</remarks>
  </class>
  <class name="ParallelEnumerable" fullname="System.Linq.ParallelEnumerable" assembly="System.Core">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>Provides a set of methods for querying objects that implement ParallelQuery{TSource}. This is the parallel equivalent of <see cref="T:System.Linq.Enumerable" />.</para>
    </summary>
    <remarks>To be added.</remarks>
  </class>
  <class name="ParallelExecutionMode" fullname="System.Linq.ParallelExecutionMode" assembly="System.Core">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>The query execution mode is a hint that specifies how the system should handle performance trade-offs when parallelizing queries.</para>
    </summary>
    <remarks />
  </class>
  <class name="ParallelMergeOptions" fullname="System.Linq.ParallelMergeOptions" assembly="System.Core">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>Specifies the preferred type of <newTerm>output merge</newTerm> to use in a query. In other words, it indicates how PLINQ should merge the results from the various partitions back into a single result sequence. This is a hint only, and may not be respected by the system when parallelizing all queries.</para>
    </summary>
    <remarks />
  </class>
  <class name="ParallelQuery" fullname="System.Linq.ParallelQuery" assembly="System.Core">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>Represents a parallel sequence.</para>
    </summary>
    <remarks>To be added.</remarks>
  </class>
  <class name="ParallelQuery&lt;TSource&gt;" fullname="System.Linq.ParallelQuery&lt;TSource&gt;" assembly="System.Core">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>Represents a parallel sequence.</para>
    </summary>
    <remarks>To be added.</remarks>
  </class>
  <class name="Queryable" fullname="System.Linq.Queryable" assembly="System.Core">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>Provides a set of static (Shared in Visual Basic) methods for querying data structures that implement <see cref="T:System.Linq.IQueryable`1" />.</para>
    </summary>
    <remarks>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>This method has at least one parameter of type <see cref="T:System.Linq.Expressions.Expression`1" /> whose type argument is one of the <see cref="T:System.Func`2" /> types. For these parameters, you can pass in a lambda expression and it will be compiled to an <see cref="T:System.Linq.Expressions.Expression`1" />.</para>
      <para>The <see cref="M:System.Linq.Queryable.Aggregate``1(System.Linq.IQueryable{``0},System.Linq.Expressions.Expression{System.Func{``0,``0,``0}})" /> method generates a <see cref="T:System.Linq.Expressions.MethodCallExpression" /> that represents calling <see cref="M:System.Linq.Queryable.Aggregate``1(System.Linq.IQueryable{``0},System.Linq.Expressions.Expression{System.Func{``0,``0,``0}})" /> itself as a constructed generic method. It then passes the <see cref="T:System.Linq.Expressions.MethodCallExpression" /> to the <see cref="M:System.Linq.IQueryProvider.Execute``1(System.Linq.Expressions.Expression)" /> method of the <see cref="T:System.Linq.IQueryProvider" /> represented by the <see cref="P:System.Linq.IQueryable.Provider" /> property of the <paramref name="source" /> parameter.</para>
      <para>The query behavior that occurs as a result of executing an expression tree that represents calling <see cref="M:System.Linq.Queryable.Aggregate``1(System.Linq.IQueryable{``0},System.Linq.Expressions.Expression{System.Func{``0,``0,``0}})" /> depends on the implementation of the type of the <paramref name="source" /> parameter. The expected behavior is that the specified function, <paramref name="func" />, is applied to each value in the source sequence and the accumulated value is returned. The first value in <paramref name="source" /> is used as the seed value for the accumulated value, which corresponds to the first parameter in <paramref name="func" />.</para>
      <para>To simplify common aggregation operations, the set of standard query operators also includes two counting methods, <see cref="M:System.Linq.Queryable.Count``1(System.Linq.IQueryable{``0})" /> and <see cref="M:System.Linq.Queryable.LongCount``1(System.Linq.IQueryable{``0})" />, and four numeric aggregation methods, namely <see cref="M:System.Linq.Queryable.Max``1(System.Linq.IQueryable{``0})" />, <see cref="M:System.Linq.Queryable.Min``1(System.Linq.IQueryable{``0})" />, <see cref="M:System.Linq.Queryable.Sum(System.Linq.IQueryable{System.Decimal})" />, and <see cref="M:System.Linq.Queryable.Average(System.Linq.IQueryable{System.Decimal})" />.</para>
    </remarks>
  </class>
</elements>