<elements>
  <summary>
    <attribution license="cc4" from="Microsoft" modified="false" />
    <para>The <see cref="N:System.Web.Profile" /> namespace contains classes that are used to work with ASP.NET user profiles in Web server applications.</para>
  </summary>
  <remarks>
    <attribution license="cc4" from="Microsoft" modified="false" />
    <para>ASP.NET profiles are used to store and retrieve user settings in a data source such as a database. Profile information and property values are managed by using a profile provider. Profile information can be stored in a Microsoft SQL Server database by using the <see cref="T:System.Web.Profile.SqlProfileProvider" /> class, or in a custom data source by using an implementation of the <see cref="T:System.Web.Profile.ProfileProvider" /> abstract class.</para>
    <para>ASP.NET profiles are configured by using the <format type="text/html"><a href="ccb9bf3a-a044-464d-b89b-5cb5a3d389dd">profile</a></format> configuration section.</para>
    <para>When an application starts that has profiles enabled, ASP.NET creates a new class of type ProfileCommon, which inherits from the <see cref="T:System.Web.Profile.ProfileBase" /> class. Strongly typed accessors are added to the ProfileCommon class for each property that is defined in the <format type="text/html"><a href="ccb9bf3a-a044-464d-b89b-5cb5a3d389dd">profile</a></format> configuration section. An instance of the ProfileCommon class is set as the value of the <see cref="P:System.Web.HttpContext.Profile" /> property of the current <see cref="T:System.Web.HttpContext" /> object. You can create a custom profile implementation that inherits from the <see cref="T:System.Web.Profile.ProfileBase" /> abstract class and that defines properties for the user profile that are not specified in the <format type="text/html"><a href="ccb9bf3a-a044-464d-b89b-5cb5a3d389dd">profile</a></format> configuration element.</para>
  </remarks>
  <class name="CustomProviderDataAttribute" fullname="System.Web.Profile.CustomProviderDataAttribute" assembly="System.Web">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>Provides a string of custom data to the provider for a profile property.</para>
    </summary>
    <remarks>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>The <see cref="T:System.Web.Profile.CustomProviderDataAttribute" /> class is used to supply a string of data with a profile property to a custom profile provider. The custom data string can be set to any string value and is set using the customProviderData attribute of the <format type="text/html"><a href="d3ea033b-751b-4bdc-8917-a5d44560808e">add</a></format> configuration element for adding profile properties. If the customProviderData attribute is set, then the value is placed in the <see cref="P:System.Configuration.SettingsProperty.Attributes" /> collection for the property and is indexed by the name "CustomProviderData."</para>
      <para>This constructor is used the .NET Framework and is not intended to be called from application code.</para>
    </remarks>
  </class>
  <class name="DefaultProfile" fullname="System.Web.Profile.DefaultProfile" assembly="System.Web">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>Represents a user-profile instance when no profile properties are defined.</para>
    </summary>
    <remarks>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>The <see cref="T:System.Web.Profile.DefaultProfile" /> class is used by ASP.NET to return a default instance of a user profile when the profile feature is enabled but no properties are defined.</para>
    </remarks>
  </class>
  <class name="ProfileAuthenticationOption" fullname="System.Web.Profile.ProfileAuthenticationOption" assembly="System.Web">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>Describes the authentication type of user profiles to be searched.</para>
    </summary>
    <remarks />
  </class>
  <class name="ProfileAutoSaveEventArgs" fullname="System.Web.Profile.ProfileAutoSaveEventArgs" assembly="System.Web">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>Provides data for the <see cref="E:System.Web.Profile.ProfileModule.ProfileAutoSaving" /> event of the <see cref="T:System.Web.Profile.ProfileModule" /> class.</para>
    </summary>
    <remarks>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>The <see cref="M:System.Web.Profile.ProfileAutoSaveEventArgs.#ctor(System.Web.HttpContext)" /> creates an instance of the <see cref="T:System.Web.Profile.ProfileAutoSaveEventArgs" /> class and sets the <see cref="P:System.Web.Profile.ProfileAutoSaveEventArgs.Context" /> property to the specified <see cref="T:System.Web.HttpContext" />.</para>
    </remarks>
  </class>
  <class name="ProfileAutoSaveEventHandler" fullname="System.Web.Profile.ProfileAutoSaveEventHandler" assembly="System.Web">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>Represents the method that will handle the <see cref="E:System.Web.Profile.ProfileModule.ProfileAutoSaving" /> event of a <see cref="T:System.Web.Profile.ProfileModule" />. </para>
    </summary>
    <remarks />
  </class>
  <class name="ProfileBase" fullname="System.Web.Profile.ProfileBase" assembly="System.Web">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>Provides untyped access to profile property values and information.</para>
    </summary>
    <remarks>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>ASP.NET uses the <see cref="T:System.Web.Profile.ProfileBase" /> class to create the class used for the user profile. When an application that has the user profile enabled is started, ASP.NET creates a new class of type ProfileCommon, which inherits from the <see cref="T:System.Web.Profile.ProfileBase" /> class. Strongly typed accessors are added to the ProfileCommon class for each property defined in the <format type="text/html"><a href="ccb9bf3a-a044-464d-b89b-5cb5a3d389dd">profile</a></format> configuration section. The strongly typed accessors of the ProfileCommon class call the <see cref="M:System.Web.Profile.ProfileBase.GetPropertyValue(System.String)" /> and <see cref="M:System.Web.Profile.ProfileBase.SetPropertyValue(System.String,System.Object)" /> methods of the <see cref="T:System.Web.Profile.ProfileBase" /> base class to retrieve and set profile property values, respectively. An instance of the ProfileCommon class is set as the value of the <see cref="P:System.Web.HttpContext.Profile" /> property for the ASP.NET application.</para>
      <block subset="none" type="note">
        <para>The base class used to generate the class stored in the <see cref="P:System.Web.HttpContext.Profile" /> property can be overridden using the inherits attribute of the <format type="text/html"><a href="ccb9bf3a-a044-464d-b89b-5cb5a3d389dd">profile</a></format> section of the configuration file. In this case you would specify a custom class that inherits from the <see cref="T:System.Web.Profile.ProfileBase" /> base class.</para>
      </block>
      <para>This constructor is not intended to be used from application code. To create an instance of a user profile, use the <see cref="Overload:System.Web.Profile.ProfileBase.Create" /> method.</para>
    </remarks>
  </class>
  <class name="ProfileEventArgs" fullname="System.Web.Profile.ProfileEventArgs" assembly="System.Web">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>Provides data for the <see cref="E:System.Web.Profile.ProfileModule.Personalize" /> event of the <see cref="T:System.Web.Profile.ProfileModule" /> class.</para>
    </summary>
    <remarks>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>The <see cref="M:System.Web.Profile.ProfileEventArgs.#ctor(System.Web.HttpContext)" /> creates an instance of the <see cref="T:System.Web.Profile.ProfileEventArgs" /> class and sets the <see cref="P:System.Web.Profile.ProfileEventArgs.Context" /> property to the specified <see cref="T:System.Web.HttpContext" />.</para>
    </remarks>
  </class>
  <class name="ProfileEventHandler" fullname="System.Web.Profile.ProfileEventHandler" assembly="System.Web">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>Represents the method that will handle the <see cref="E:System.Web.Profile.ProfileModule.Personalize" /> event of a <see cref="T:System.Web.Profile.ProfileModule" />. </para>
    </summary>
    <remarks />
  </class>
  <class name="ProfileGroupBase" fullname="System.Web.Profile.ProfileGroupBase" assembly="System.Web">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>Provides untyped access to grouped ASP.NET profile property values.</para>
    </summary>
    <remarks>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>ASP.NET uses the <see cref="T:System.Web.Profile.ProfileGroupBase" /> class to create grouped properties in the <see cref="P:System.Web.HttpContext.Profile" /> property for the current <see cref="T:System.Web.HttpContext" />. When properties are specified as a group of properties using the <format type="text/html"><a href="b4e3672f-9653-4034-a178-fb358b02730e">group</a></format> element, ASP.NET creates a new class with strongly typed accessors for each property in the group. The new class inherits the <see cref="T:System.Web.Profile.ProfileGroupBase" /> base class.</para>
      <para>This class is not intended to be created from your code.</para>
    </remarks>
  </class>
  <class name="ProfileInfo" fullname="System.Web.Profile.ProfileInfo" assembly="System.Web">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>Provides information about a user profile.</para>
    </summary>
    <remarks>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>This <see cref="T:System.Web.Profile.ProfileInfo" /> constructor is not intended to be used from your code. Instead, use the <see cref="M:System.Web.Profile.ProfileInfo.#ctor(System.String,System.Boolean,System.DateTime,System.DateTime,System.Int32)" />.</para>
      <para>
        <see cref="T:System.Web.Profile.ProfileInfo" /> objects are constructed and returned as part of a <see cref="T:System.Web.Profile.ProfileInfoCollection" /> by the <see cref="M:System.Web.Profile.ProfileProvider.GetAllProfiles(System.Web.Profile.ProfileAuthenticationOption,System.Int32,System.Int32,System.Int32@)" />, <see cref="M:System.Web.Profile.ProfileProvider.GetAllInactiveProfiles(System.Web.Profile.ProfileAuthenticationOption,System.DateTime,System.Int32,System.Int32,System.Int32@)" />, <see cref="M:System.Web.Profile.ProfileProvider.FindProfilesByUserName(System.Web.Profile.ProfileAuthenticationOption,System.String,System.Int32,System.Int32,System.Int32@)" />, and <see cref="M:System.Web.Profile.ProfileProvider.FindInactiveProfilesByUserName(System.Web.Profile.ProfileAuthenticationOption,System.String,System.DateTime,System.Int32,System.Int32,System.Int32@)" /> methods of a <see cref="T:System.Web.Profile.ProfileProvider" />.</para>
    </remarks>
  </class>
  <class name="ProfileInfoCollection" fullname="System.Web.Profile.ProfileInfoCollection" assembly="System.Web">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>A collection of <see cref="T:System.Web.Profile.ProfileInfo" /> objects.</para>
    </summary>
    <remarks>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>A <see cref="T:System.Web.Profile.ProfileInfoCollection" /> is constructed by profile provider implementers and returned from the <see cref="M:System.Web.Profile.ProfileProvider.GetAllProfiles(System.Web.Profile.ProfileAuthenticationOption,System.Int32,System.Int32,System.Int32@)" />, <see cref="M:System.Web.Profile.ProfileProvider.GetAllInactiveProfiles(System.Web.Profile.ProfileAuthenticationOption,System.DateTime,System.Int32,System.Int32,System.Int32@)" />, <see cref="M:System.Web.Profile.ProfileProvider.FindProfilesByUserName(System.Web.Profile.ProfileAuthenticationOption,System.String,System.Int32,System.Int32,System.Int32@)" />, and <see cref="M:System.Web.Profile.ProfileProvider.FindInactiveProfilesByUserName(System.Web.Profile.ProfileAuthenticationOption,System.String,System.DateTime,System.Int32,System.Int32,System.Int32@)" /> methods of the <see cref="T:System.Web.Profile.ProfileProvider" /> abstract class.</para>
    </remarks>
  </class>
  <class name="ProfileManager" fullname="System.Web.Profile.ProfileManager" assembly="System.Web">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>Manages user profile data and settings.</para>
    </summary>
    <remarks>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>The <see cref="T:System.Web.Profile.ProfileManager" /> uses the <see cref="P:System.Web.Profile.ProfileManager.ApplicationName" /> property to associate profile information with different applications. This enables multiple applications to use the same database to store user information without running into conflicts between duplicate users. Multiple ASP.NET applications can use the same user database by specifying the same value in the <see cref="P:System.Web.Profile.ProfileManager.ApplicationName" /> property. The <see cref="P:System.Web.Profile.ProfileManager.ApplicationName" /> property can be set programmatically, or it can be set declaratively in the configuration file for the Web application by using the applicationName attribute.</para>
      <para>If a value is not specified for the applicationName attribute in the configuration file for the Web application, then the profile providers included with the .NET Framework use the <see cref="P:System.Web.Hosting.HostingEnvironment.ApplicationVirtualPath" /> property value for ASP.NET applications. For non-ASP.NET applications, the default value is the <see cref="P:System.Diagnostics.ProcessModule.ModuleName" /> property value, without the file extension.</para>
      <para>The <see cref="P:System.Web.Profile.ProfileManager.ApplicationName" /> property exposes the <see cref="P:System.Configuration.SettingsProvider.ApplicationName" /> property of the default profile provider. The default profile provider is specified using the defaultProvider attribute of the <format type="text/html"><a href="ccb9bf3a-a044-464d-b89b-5cb5a3d389dd">profile</a></format> configuration element. If the user profile contains properties that are managed by a profile provider other than the default provider, they may be configured with a different application name. To access the application name of a profile provider other than the default provider, obtain a reference to the profile provider using the <see cref="P:System.Web.Profile.ProfileManager.Providers" /> property and access the <see cref="P:System.Configuration.SettingsProvider.ApplicationName" /> property of the provider directly.</para>
      <block subset="none" type="note">
        <para>Because a single default profile provider instance is used for all of the requests served by an <see cref="T:System.Web.HttpApplication" /> object, you can have multiple requests executing concurrently and attempting to set the <see cref="P:System.Web.Profile.ProfileManager.ApplicationName" /> property value. The <see cref="P:System.Web.Profile.ProfileManager.ApplicationName" /> property is not thread safe for multiple writes, and changing the <see cref="P:System.Web.Profile.ProfileManager.ApplicationName" /> property value can result in unexpected behavior for multiple users of an application. It is recommended that you avoid writing code that allows users to set the <see cref="P:System.Web.Profile.ProfileManager.ApplicationName" /> property unless you require it. An example of an application where setting the <see cref="P:System.Web.Profile.ProfileManager.ApplicationName" /> property may be required is an administrative application that manages profile data for multiple applications. Such an application should be a single-user application and not a Web application.</para>
      </block>
    </remarks>
  </class>
  <class name="ProfileMigrateEventArgs" fullname="System.Web.Profile.ProfileMigrateEventArgs" assembly="System.Web">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>Provides data for the <see cref="E:System.Web.Profile.ProfileModule.MigrateAnonymous" /> event of the <see cref="T:System.Web.Profile.ProfileModule" /> class.</para>
    </summary>
    <remarks>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>The <see cref="M:System.Web.Profile.ProfileMigrateEventArgs.#ctor(System.Web.HttpContext,System.String)" /> creates an instance of the <see cref="T:System.Web.Profile.ProfileMigrateEventArgs" /> class, sets the <see cref="P:System.Web.Profile.ProfileMigrateEventArgs.Context" /> property to the specified <see cref="T:System.Web.HttpContext" />, and sets the <see cref="P:System.Web.Profile.ProfileMigrateEventArgs.AnonymousID" /> property to the specified <paramref name="anonymousId" />.</para>
    </remarks>
  </class>
  <class name="ProfileMigrateEventHandler" fullname="System.Web.Profile.ProfileMigrateEventHandler" assembly="System.Web">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>Represents the method that will handle the <see cref="E:System.Web.Profile.ProfileModule.MigrateAnonymous" /> event of the <see cref="T:System.Web.Profile.ProfileModule" /> class.</para>
    </summary>
    <remarks />
  </class>
  <class name="ProfileModule" fullname="System.Web.Profile.ProfileModule" assembly="System.Web">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>Manages the creation of the user profile and profile events. This class cannot be inherited.</para>
    </summary>
    <remarks>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>This constructor is not intended to be called from application code.</para>
      <para>An <see cref="T:System.Web.HttpApplication" /> is created when an ASP.NET application is started. The <see cref="T:System.Web.HttpApplication" /> calls the <see cref="T:System.Web.Profile.ProfileModule" /> constructor to create the <see cref="T:System.Web.Profile.ProfileModule" /> for the application. The <see cref="T:System.Web.Profile.ProfileModule" /> is specified in the configuration for an application.</para>
    </remarks>
  </class>
  <class name="ProfileProvider" fullname="System.Web.Profile.ProfileProvider" assembly="System.Web">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>Defines the contract that ASP.NET implements to provide profile services using custom profile providers.</para>
    </summary>
    <remarks>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>You are not required to implement a constructor for a class that inherits the <see cref="T:System.Web.Profile.ProfileProvider" /> abstract class. Initialization values for a <see cref="T:System.Web.Profile.ProfileProvider" /> implementation are passed to the <see cref="M:System.Configuration.Provider.ProviderBase.Initialize(System.String,System.Collections.Specialized.NameValueCollection)" /> method implementation.</para>
    </remarks>
  </class>
  <class name="ProfileProviderAttribute" fullname="System.Web.Profile.ProfileProviderAttribute" assembly="System.Web">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>Identifies the profile provider for a user-profile property.</para>
    </summary>
    <remarks>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>The <see cref="T:System.Web.Profile.ProfileProviderAttribute" /> class is used to identify the profile provider for a property of a custom profile implementation. A custom profile implementation is a class that inherits from the <see cref="T:System.Web.Profile.ProfileBase" /> abstract class and defines properties for the user profile that are not specified in the <format type="text/html"><a href="ccb9bf3a-a044-464d-b89b-5cb5a3d389dd">profile</a></format> configuration element.</para>
    </remarks>
  </class>
  <class name="ProfileProviderCollection" fullname="System.Web.Profile.ProfileProviderCollection" assembly="System.Web">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>A collection of objects that inherit the <see cref="T:System.Web.Profile.ProfileProvider" /> abstract class.</para>
    </summary>
    <remarks>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>This constructor is not intended to be used from your code. The profile providers for an application are exposed as a read-only <see cref="T:System.Web.Profile.ProfileProviderCollection" /> through the <see cref="P:System.Web.Profile.ProfileManager.Providers" /> property of the <see cref="T:System.Web.Profile.ProfileManager" /> class.</para>
    </remarks>
  </class>
  <class name="SettingsAllowAnonymousAttribute" fullname="System.Web.Profile.SettingsAllowAnonymousAttribute" assembly="System.Web">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>Identifies whether a profile property can be set or accessed for an anonymous user.</para>
    </summary>
    <remarks>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>The <see cref="T:System.Web.Profile.SettingsAllowAnonymousAttribute" /> class is used to identify whether a property of a custom profile implementation can be accessed if the user is an anonymous user. For information about enabling anonymous identification, see the <format type="text/html"><a href="2bd927ef-9057-4703-9c55-4cfb6d7d0929">anonymousIdentification</a></format> configuration element.</para>
      <para>If no <see cref="T:System.Web.Profile.SettingsAllowAnonymousAttribute" /> is specified for a profile property, anonymous access to the profile property is not allowed.</para>
      <para>A custom profile implementation is a class that inherits from the <see cref="T:System.Web.Profile.ProfileBase" /> abstract class and defines properties for the user profile that are not specified in the <format type="text/html"><a href="ccb9bf3a-a044-464d-b89b-5cb5a3d389dd">profile</a></format> configuration element.</para>
    </remarks>
  </class>
  <class name="SqlProfileProvider" fullname="System.Web.Profile.SqlProfileProvider" assembly="System.Web">
    <summary>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>Manages storage of profile information for an ASP.NET application in a SQL Server database.</para>
    </summary>
    <remarks>
      <attribution license="cc4" from="Microsoft" modified="false" />
      <para>ASP.NET calls the <see cref="M:System.Web.Profile.SqlProfileProvider.#ctor" /> constructor to create an instance of the <see cref="T:System.Web.Profile.SqlProfileProvider" /> class using the values specified in the configuration file for the application. This constructor is not intended to be used from your code.</para>
    </remarks>
  </class>
</elements>